[Libreoffice-commits] online.git: 2 commits - loolwsd/AUTHORS loolwsd/LOOLBroker.cpp

Tor Lillqvist tml at collabora.com
Tue Mar 1 11:25:47 UTC 2016


 loolwsd/AUTHORS        |    1 -
 loolwsd/LOOLBroker.cpp |   14 +++++++-------
 2 files changed, 7 insertions(+), 8 deletions(-)

New commits:
commit aa4fe42d24b61eef86e44851fe044128ca85fca1
Author: Tor Lillqvist <tml at collabora.com>
Date:   Tue Mar 1 13:25:09 2016 +0200

    English

diff --git a/loolwsd/AUTHORS b/loolwsd/AUTHORS
index a58d2b8..e69de29 100644
--- a/loolwsd/AUTHORS
+++ b/loolwsd/AUTHORS
@@ -1 +0,0 @@
-Tor Lillqvist <tml at iki.fi> <tml at collabora.com>


More information about the Libreoffice-commits mailing list
diff --git a/loolwsd/LOOLBroker.cpp b/loolwsd/LOOLBroker.cpp
index 05124a6..c90f5fa 100644
--- a/loolwsd/LOOLBroker.cpp
+++ b/loolwsd/LOOLBroker.cpp
@@ -248,12 +248,12 @@ public:
     }
 
     /// Sync ChildProcess instances with its child.
-    /// Returns the number of empty childs.
-    size_t syncChilds()
+    /// Returns the number of empty children.
+    size_t syncChildren()
     {
         std::lock_guard<std::recursive_mutex> lock(forkMutex);
 
-        Log::trace("Synching Childs.");
+        Log::trace("Synching children.");
         size_t empty_count = 0;
         for (auto it = _childProcesses.begin(); it != _childProcesses.end(); )
         {
@@ -411,7 +411,7 @@ public:
                     const auto duration = (std::chrono::steady_clock::now() - lastMaintenanceTime);
                     if (duration >= std::chrono::seconds(10))
                     {
-                        syncChilds();
+                        syncChildren();
                         lastMaintenanceTime = std::chrono::steady_clock::now();
                     }
 
@@ -871,7 +871,7 @@ int main(int argc, char** argv)
                 Util::removeFile(childPath, true);
             }
 
-            pipeHandler.syncChilds();
+            pipeHandler.syncChildren();
             timeoutCounter = 0;
         }
         else if (pid < 0)
@@ -898,13 +898,13 @@ int main(int argc, char** argv)
         {
             std::lock_guard<std::recursive_mutex> lock(forkMutex);
 
-            const int empty = pipeHandler.syncChilds();
+            const int empty = pipeHandler.syncChildren();
             const int total = _childProcesses.size();
 
             // Figure out how many children we need. Always create at least as many
             // as configured pre-spawn or one more than requested (whichever is larger).
             int spawn = std::max(static_cast<int>(forkCounter) + 1, numPreSpawnedChildren);
-            Log::debug() << "Creating " << spawn << " childs. Current Total: "
+            Log::debug() << "Creating " << spawn << (spawn == 1 ? "child" : "children") << ". Current total: "
                          << total << ", Empty: " << empty << Log::end;
             do
             {
commit 0cf40c50ea6a9fb6da2720ce6d0fb839c8f2e363
Author: Tor Lillqvist <tml at collabora.com>
Date:   Tue Mar 1 13:10:18 2016 +0200

    Anybody interested can check git log
